pandocfilters: A Python module for writing pandoc filters
=========================================================

Description
-----------

A python module for writing pandoc filters.

License
-------

BSD 3-Clause License


Upstream Contact
----------------

Author: John MacFarlane Home page: https://github.com/jgm/pandocfilters

Special Update/Build Instructions
---------------------------------

Download the last release from
https://pypi.python.org/pypi/pandocfilters
